@@ -18,13 +18,27 @@
 ##  some of these functions.
 ##
 
+plot.mcd <- function(x,
+                   which=c("all", "dd","distance","qqchi2","tolellipse"),
+                   classic=FALSE,
+                   ask=(which=="all" && dev.interactive()),
+                   cutoff, 
+                   id.n,
+                   tol.inv = 1e-7, ...){
+    if (!inherits(x, "mcd"))
+        stop("Use only with 'mcd' objects") 
+        
+    covPlot(x$X, which=which, classic=classic, ask=ask, cutoff=cutoff, mcd=x, id.n=id.n, tol.inv=tol.inv, ...)
+}
+
 covPlot <- function(x, 
-                   plotname = c("dd","distance","qqchi2","tolellipse"),
-                   classic = FALSE,
+                   which=c("all", "dd","distance","qqchi2","tolellipse"),
+                   classic=FALSE,
+                   ask=FALSE,
                    mcd, 
                    cutoff, 
-                   nid,
-                   tol.inv = 1e-7){
+                   id.n,
+                   tol.inv = 1e-7, ...){
 
 ##@bdescr
 ##  Make plots based on the covariance structure of a data set:
@@ -52,7 +66,7 @@ covPlot <- function(x,
 ##@edescr
 ##
 ##@in  x                 : [matrix] A data.frame or matrix, n > 2*p
-##@in  plotname          : [character] A plot option, one of:
+##@in  which          : [character] A plot option, one of:
 ##                            classic: index plot of the classical mahalanobis distances
 ##                            robust:  index plot of the robust mahalanobis distances
 ##                            dd:      distance-distance plot
@@ -64,7 +78,7 @@ covPlot <- function(x,
 ##@in  mcd               : [mcd object] An object of type mcd - its attributes 
 ##                                      center and cov will be used
 ##@in  cutoff            : [number] The cutoff value for the distances 
-##@in  nid               : [number] number of observations to be identified with a label.
+##@in  id.n               : [number] number of observations to be identified with a label.
 ##                                  Defaults to the number of observations with distance
 ##                                  larger than cutoff 
 ##@in  tol.inv           : [number] tolerance to be used for computing the inverse - see 'solve'.
@@ -74,54 +88,58 @@ covPlot <- function(x,
 #       data sets, like milk or aircraft
 
 
-mydistplot <- function(x, cutoff, classic = FALSE, nid){
+mydistplot <- function(x, cutoff, classic = FALSE, id.n){
 ##  Index Plot:
 ##  Plot the vector x (robust or mahalanobis distances) against 
-##  the observation indexes. Identify by a label the nid
-##  observations with largest value of x. If nid is not supplied, 
+##  the observation indexes. Identify by a label the id.n
+##  observations with largest value of x. If id.n is not supplied, 
 ##  calculate it as the number of observations larger than cutoff.
 ##  Use cutoff to draw a horisontal line.
 ##  Use classic=FALSE/TRUE to choose the label of the vertical axes
 
     n <- length(x)
-    if(missing(nid))
-        nid <- length(which(x>cutoff))
+    if(missing(id.n))
+        id.n <- length(which(x>cutoff))
     if(classic)
         ylab="Square Root of Mahalanobis distance"
     else
         ylab="Square Root of Robust distance"
     plot(x, ylab=ylab, xlab="Index", type="p")
-    label(1:n, x, nid)
+    label(1:n, x, id.n)
     abline(h=cutoff)
+
+    title(main="Distance Plot")
 }
 
-myddplot <- function(md, rd, cutoff, nid){
+myddplot <- function(md, rd, cutoff, id.n){
 ##  Distance-Distance Plot:
 ##  Plot the vector y=rd (robust distances) against 
-##  x=md (mahalanobis distances). Identify by a label the nid
-##  observations with largest rd. If nid is not supplied, calculate
+##  x=md (mahalanobis distances). Identify by a label the id.n
+##  observations with largest rd. If id.n is not supplied, calculate
 ##  it as the number of observations larger than cutoff. Use cutoff
 ##  to draw a horisontal and a vertical line. Draw also a dotted line
 ##  with a slope 1.
     n <- length(md)
-    if(missing(nid))
-        nid <- length(which(rd>cutoff))
+    if(missing(id.n))
+        id.n <- length(which(rd>cutoff))
     xlab <- "Mahalanobis distance"
     ylab <- "Robust distance"
     plot(md, rd, xlab=xlab, ylab=ylab, type="p")
-    label(md,rd,nid)
+    label(md,rd,id.n)
     abline(0, 1, lty=2)
     abline(v=cutoff)
     abline(h=cutoff)
+
+    title(main="Distance-Distance Plot")
 }
 
-qqplot <- function(x, p, cutoff, classic=FALSE, nid){
+qqplot <- function(x, p, cutoff, classic=FALSE, id.n){
 ##  Chisquare QQ-Plot:
 ##  Plot the vector x (robust or mahalanobis distances) against 
 ##  the square root of the quantiles of the chi-squared distribution
 ##  with p degrees of freedom.
-##  Identify by a label the nid observations with largest value of x.
-##  If nid is not supplied, calculate it as the number of observations
+##  Identify by a label the id.n observations with largest value of x.
+##  If id.n is not supplied, calculate it as the number of observations
 ##  larger than cutoff.
 ##  Use classic=FALSE/TRUE to choose the label of the vertical axes
 
@@ -133,8 +151,8 @@ qqplot <- function(x, p, cutoff, classic=FALSE, nid){
     if(missing(cutoff))
         cutoff <- sqrt(qchisq(0.975, p))
 
-    if(missing(nid))
-        nid <- length(which(x>cutoff))
+    if(missing(id.n))
+        id.n <- length(which(x>cutoff))
 
     qq <- sqrt(qchisq(((1:n)-1/3)/(n+1/3), p))
 
@@ -148,22 +166,23 @@ qqplot <- function(x, p, cutoff, classic=FALSE, nid){
         ylab="Robust distance"
 
     plot(qq, x, xlab="Square root of the quantiles of the chi-squared distribution", ylab=ylab, type="p")
-    if(nid > 0){
-        ind <- (n-nid+1):n
+    if(id.n > 0){
+        ind <- (n-id.n+1):n
         xrange <- par("usr")
         xrange <- xrange[2] - xrange[1]
         text(qq[ind] + xrange/50, x[ind], ix[ind])
     }
     abline(0, 1, lty=2)
+    title(main="Chisquare QQ-Plot")
 }
 
-label <- function(x, y, nid=3){
-    if(nid > 0) {
+label <- function(x, y, id.n=3){
+    if(id.n > 0) {
         xrange <- par("usr")
         xrange <- xrange[2] - xrange[1]
         n <- length(y)
         ind <- sort(y, index.return=TRUE)$ix
-        ind <- ind[(n-nid+1):n]
+        ind <- ind[(n-id.n+1):n]
         text(x[ind] + xrange/50, y[ind], ind)
     }
 }
@@ -184,6 +203,12 @@ label <- function(x, y, nid=3){
     if(missing(cutoff))
         cutoff <- sqrt(qchisq(0.975, p))
 
+    if(!missing(id.n) && !is.null(id.n)){
+        id.n <- as.integer(id.n)
+        if(id.n < 0 || id.n > n)
+            stop("`id.n' must be in {1,..,",n,"}") 
+    }
+
     if(missing(mcd))
         mcd <- covMcd(x)
 
@@ -196,50 +221,57 @@ label <- function(x, y, nid=3){
     md <- mahalanobis(x, apply(x,2,mean), var(x), tol.inv=tol.inv)
     md <- sqrt(md)
 
-    plotname <- match.arg(plotname)
+    which <- match.arg(which)
     rd <- mahalanobis(x, mcd$center, mcd$cov, tol.inv=tol.inv)
     rd <- sqrt(rd)
 
-    if(!classic || plotname == "dd")    
+    if(!classic || which == "dd")    
         par(mfrow=c(1,1), pty="m")
     else
         par(mfrow=c(1,2), pty="m")
 
-    if(plotname == "distance"){    
-        mydistplot(rd, cutoff, nid=nid)                     # index plot of mahalanobis distances
+    if (ask) {
+        op <- par(ask = TRUE)
+        on.exit(par(op))
+    } 
+
+    if(which == "all" || which == "distance"){    
+        mydistplot(rd, cutoff, id.n=id.n)                     # index plot of mahalanobis distances
         if(classic)
-            mydistplot(md, cutoff, classic=TRUE, nid=nid)   # index plot of robust distances
+            mydistplot(md, cutoff, classic=TRUE, id.n=id.n)   # index plot of robust distances
     }
 
-    if(plotname == "dd"){    
-        myddplot(md, rd, cutoff=cutoff, nid=nid)    # distance-distance plot
+    if(which == "all" || which == "dd"){    
+        myddplot(md, rd, cutoff=cutoff, id.n=id.n)    # distance-distance plot
     }
-    if(plotname == "qqchi2"){    
-        qqplot(rd, p, cutoff=cutoff, nid=nid)       # qq-plot of the robust distances versus the 
+
+    if(which == "all" || which == "qqchi2"){    
+        qqplot(rd, p, cutoff=cutoff, id.n=id.n)     # qq-plot of the robust distances versus the 
                                                     # quantiles of the chi-squared distribution
         if(classic)
-            qqplot(md, p, cutoff=cutoff, classic=TRUE, nid=nid)
+            qqplot(md, p, cutoff=cutoff, classic=TRUE, id.n=id.n)
                                                     # qq-plot of the mahalanobis distances
     }
-    if(plotname == "tolellipse"){    
-       tolellipse(x, mcd=mcd, cutoff=cutoff, nid=nid, classic=classic, tol.inv=tol.inv)
+
+    if(which == "all" || which == "tolellipse"){    
+       tolellipse(x, mcd=mcd, cutoff=cutoff, id.n=id.n, classic=classic, tol.inv=tol.inv)
                                                 # qq-plot of the robust distances versus the 
                                                 # quantiles of the chi-squared distribution
     }
 }
 
 ddplot <- function(x,...){
-    covPlot(x, plot="dd", ...)
+    covPlot(x, which="dd", ...)
 }
 
 distplot <- function(x,...){
-    covPlot(x, plot="distance", ...)
+    covPlot(x, which="distance", ...)
 }
 
 chi2qqplot <- function(x,...){
-    covPlot(x, plot="qqchi2", ...)
+    covPlot(x, which="qqchi2", ...)
 }
 
 ellipse <- function(x,...){
-    covPlot(x, plot="tolellipse", ...)
+    covPlot(x, which="tolellipse", ...)
 }
