@@ -21,19 +21,26 @@ dodata <- function(nrep=1, time=FALSE, short=FALSE, full=TRUE, method = c("FASTM
 ##@in  full              : [boolean] whether to print the estimated cente and covariance matrix 
 ##@in  method            : [character] select a method: one of (FASTMCD, MASS) 
 
-    domcd <- function(x, xname, nrep=1){ 
+    domcd <- function(x, xname, nrep=1){
+        n <- dim(x)[1]
+        p <- dim(x)[2]
         if(method == "MASS"){
             mcd<-cov.mcd(x)
-            quan <- as.integer((dim(x)[1] + (dim(x)[2] + 1) + 1)/2)   #default: (n+p+1)/2
+            quan <- as.integer(floor((n + p + 1)/2))   #default: floor((n+p+1)/2)
         }            
         else{
             mcd<-covMcd(x, print.it=FALSE)
             quan <- as.integer(mcd$quan)
         }
-        crit <- log(mcd$crit)
+        
+        if(method == "MASS") 
+            crit <- mcd$crit
+        else
+            crit <- log(mcd$crit)
+            
         if(time){
            xtime <- system.time(dorep(x, nrep, method))[1]/nrep
-            xres <- sprintf("%3d %3d %3d %12.6f %10.3f\n", dim(x)[1], dim(x)[2], quan, crit, xtime)
+           xres <- sprintf("%3d %3d %3d %12.6f %10.3f\n", dim(x)[1], dim(x)[2], quan, crit, xtime)
         }
         else{
             xres <- sprintf("%3d %3d %3d %12.6f\n", dim(x)[1], dim(x)[2], quan, crit)
@@ -67,6 +74,7 @@ dodata <- function(nrep=1, time=FALSE, short=FALSE, full=TRUE, method = c("FASTM
 
 
     data(heart)
+    data(stars)
     data(phosphor)
     data(stackloss)
     data(coleman)
@@ -85,6 +93,7 @@ dodata <- function(nrep=1, time=FALSE, short=FALSE, full=TRUE, method = c("FASTM
     cat("Data Set               n   p  Half LOG(obj)        Time\n")
     cat("========================================================\n")
     domcd(heart.x,data(heart), nrep)
+    domcd(stars,data(stars), nrep)
     domcd(phosphor.x,data(phosphor), nrep)
     domcd(stack.x,data(stackloss), nrep)
     domcd(coleman.x,data(coleman), nrep)
@@ -98,7 +107,7 @@ dodata <- function(nrep=1, time=FALSE, short=FALSE, full=TRUE, method = c("FASTM
     cat("========================================================\n")
 }
 
-dogen <- function(nrep=1, eps=0.4, method=c("FASTMCD", "MASS")){
+dogen <- function(nrep=1, eps=0.49, method=c("FASTMCD", "MASS")){
 
     domcd <- function(x, nrep=1){ 
         gc()
@@ -110,14 +119,12 @@ dogen <- function(nrep=1, eps=0.4, method=c("FASTMCD", "MASS")){
     set.seed(1234)
 
     library(rrcov)
+    library(MASS)
     method <- match.arg(method)
-    if(method == "MASS")
-        library(MASS)
 
     ap <- c(2, 5, 10, 20, 30)
     an <- c(100, 500, 1000, 10000, 50000)
 
-
     tottime <- 0
     cat("     n   p       Time\n")
     cat("=====================\n")
@@ -125,8 +132,11 @@ dogen <- function(nrep=1, eps=0.4, method=c("FASTMCD", "MASS")){
         for(j in 1:length(ap)) {
             n <- an[i]
             p <- ap[j]
-            if(5*p <= n)
-                tottime <- tottime + domcd(gendata(n, p, eps), nrep)
+            if(5*p <= n){
+                xx <- gendata(n, p, eps)
+                X <- xx$X
+                tottime <- tottime + domcd(X, nrep)
+            }
         } 
     }
     
@@ -134,6 +144,19 @@ dogen <- function(nrep=1, eps=0.4, method=c("FASTMCD", "MASS")){
     cat("Total time: ", tottime*nrep, "\n")
 }
 
+docheck <- function(n, p, eps){
+    xx <- gendata(n,p,eps)
+    mcd <- covMcd(xx$X)
+    check(mcd, xx$xind)
+}
+
+check <- function(mcd, xind){
+##  check if mcd is robust w.r.t xind, i.e. check how many of xind
+##  did not get zero weight
+    mymatch <- xind %in% which(mcd$mcd.wt == 0)
+    length(xind) - length(which(mymatch))    
+}
+
 dorep <- function(x, nrep=1, method=c("FASTMCD","MASS")){ 
 
     method <- match.arg(method)
@@ -154,6 +177,8 @@ dorep <- function(x, nrep=1, method=c("FASTMCD","MASS")){
 #
 gendata <- function(n,p,eps=0,b=10){
 
+    if(missing(n) || missing(p))
+        stop("Please specify (n,p)")
     if(eps < 0 || eps >= 0.5)
         stop(message="eps must be in [0,0.5)")
     X <- mvrnorm(n,rep(0,p),diag(1,nrow=p,ncol=p))
@@ -161,11 +186,9 @@ gendata <- function(n,p,eps=0,b=10){
     if(nbad > 0){
         Xbad <- mvrnorm(nbad,rep(b,p),diag(1,nrow=p,ncol=p))
         xind <- sample(n,nbad)
-        for(i in 1:nbad){
-            X[xind[i],] <- Xbad[i,] 
-        }
+        X[xind,] <- Xbad
     }
-    X
+    list(X=X, xind=xind)
 }
 
 pad.right <- function(z, pads)
